@@ -19,15 +19,11 @@ from utils.namedtuple import namedtuple
 
 
 class EdgeLines(object):
-    def __init__(self, metrix, points=None):
+    def __init__(self, metrix):
         self.xy = None
         self.cellSize = metrix.cellSize
         self.stroking = False
         self.polylines = []
-        self.crossPoints = []
-
-        if points:
-            self.crossPoints = points
 
     def moveTo(self, x, y=None):
         self.stroking = False
@@ -53,44 +49,8 @@ class EdgeLines(object):
             if self.polylines[-1][-1] == elem:
                 return
 
-            start = self.polylines[-1][-1]
-            crosspoint = self.getCrosspoint(start, elem)
-            if crosspoint:
-                if start.x > elem.x:  # line goes right to left
-                    jump_width = - (self.cellSize / 2)
-                else:
-                    jump_width = self.cellSize / 2
-
-                if start.y == crosspoint.y:  # holizonal line
-                    p = XY(crosspoint.x - jump_width, crosspoint.y)
-                    self.lineTo(p)
-
-                    p = XY(crosspoint.x + jump_width, crosspoint.y)
-                    self.moveTo(p)
-                    self.lineTo(elem)
-                    return
-                else:
-                    raise
-
         self.polylines[-1].append(elem)
 
-    def getCrosspoint(self, start, end):
-        if start.x > end.x:
-            p1 = end
-            p2 = start
-        else:
-            p1 = start
-            p2 = end
-
-        for p in self.crossPoints:
-            if p1.x <= p.x and p.x <= p2.x and \
-               ((p1.y <= p2.y and p1.y <= p.y and p.y <= p2.y) or \
-                (p1.y > p2.y and p2.y <= p.y and p.y <= p1.y)) and \
-               (p.y - p1.y) * (p2.x - p1.x) == (p2.y - p1.y) * (p.x - p1.x):
-                return p
-
-        return None
-
     def lines(self):
         lines = []
         for line in self.polylines:
@@ -117,7 +77,6 @@ def scale(value, ratio):
 
         ret = EdgeLines(Dummy(value.cellSize))
         ret.polylines = scale(value.polylines, ratio)
-        ret.crossPoints = scale(value.crossPoints, ratio)
     elif isinstance(value, int):
         ret = value * ratio
     else:
@@ -412,9 +371,6 @@ class EdgeMetrix(object):
     def labelbox(self):
         pass
 
-    def jumps(self):
-        return self.edge.crosspoints
-
 
 class LandscapeEdgeMetrix(EdgeMetrix):
     def heads(self):
@@ -455,7 +411,7 @@ class LandscapeEdgeMetrix(EdgeMetrix):
         node2 = self.metrix.node(self.edge.node2)
         cell2 = self.metrix.cell(self.edge.node2)
 
-        shaft = EdgeLines(self.metrix, self.edge.crosspoints)
+        shaft = EdgeLines(self.metrix)
         if dir == 'right':
             shaft.moveTo(node1.right())
 
@@ -557,6 +513,7 @@ class LandscapeEdgeMetrix(EdgeMetrix):
 
     def labelbox(self):
         span = XY(self.metrix.spanWidth, self.metrix.spanHeight)
+        node = XY(self.metrix.nodeWidth, self.metrix.nodeHeight)
 
         dir = self.direction()
         node1 = self.metrix.cell(self.edge.node1)
@@ -576,9 +533,9 @@ class LandscapeEdgeMetrix(EdgeMetrix):
 
         elif dir == 'right-up':
             box = (node2.left().x - span.x,
-                   node2.left().y,
+                   node1.top().y - node.y / 2,
                    node2.bottomLeft().x,
-                   node2.bottomLeft().y)
+                   node1.top().y)
 
         elif dir == 'right-down':
             box = (node1.right().x,
@@ -654,7 +611,7 @@ class PortraitEdgeMetrix(EdgeMetrix):
         node2 = self.metrix.node(self.edge.node2)
         cell2 = self.metrix.cell(self.edge.node2)
 
-        shaft = EdgeLines(self.metrix, self.edge.crosspoints)
+        shaft = EdgeLines(self.metrix)
         if dir in ('up', 'right-up', 'same', 'right'):
             if dir == 'right' and not self.edge.skipped:
                 shaft.moveTo(node1.right())
@@ -768,12 +725,18 @@ class PortraitEdgeMetrix(EdgeMetrix):
                        node1.topRight().x + span.x / 4,
                        node1.topRight().y - span.y / 2)
 
-        elif dir in ('left-down', 'down'):
+        elif dir == 'down':
             box = (node2.top().x + span.x / 4,
                    node2.top().y - span.y / 2,
                    node2.topRight().x + span.x / 4,
                    node2.topRight().y)
 
+        elif dir == 'left-down':
+            box = (node1.bottomLeft().x,
+                   node1.bottomLeft().y,
+                   node1.bottom().x,
+                   node1.bottom().y + span.y / 2)
+
         # shrink box
         box = (box[0] + span.x / 8, box[1],
                box[2] - span.x / 8, box[3])
@@ -804,7 +767,7 @@ class FlowchartLandscapeEdgeMetrix(LandscapeEdgeMetrix):
             node2 = self.metrix.node(self.edge.node2)
             cell2 = self.metrix.cell(self.edge.node2)
 
-            shaft = EdgeLines(self.metrix, self.edge.crosspoints)
+            shaft = EdgeLines(self.metrix)
             shaft.moveTo(node1.bottom())
 
             if self.edge.skipped:
@@ -823,6 +786,7 @@ class FlowchartLandscapeEdgeMetrix(LandscapeEdgeMetrix):
         return shaft
 
     def labelbox(self):
+        dir = self.direction()
         if dir == 'right':
             span = XY(self.metrix.spanWidth, self.metrix.spanHeight)
             node1 = self.metrix.node(self.edge.node1)
@@ -869,7 +833,7 @@ class FlowchartPortraitEdgeMetrix(PortraitEdgeMetrix):
             node2 = self.metrix.node(self.edge.node2)
             cell2 = self.metrix.cell(self.edge.node2)
 
-            shaft = EdgeLines(self.metrix, self.edge.crosspoints)
+            shaft = EdgeLines(self.metrix)
             shaft.moveTo(node1.right())
 
             if self.edge.skipped:
@@ -889,6 +853,7 @@ class FlowchartPortraitEdgeMetrix(PortraitEdgeMetrix):
         return shaft
 
     def labelbox(self):
+        dir = self.direction()
         if dir == 'right':
             span = XY(self.metrix.spanWidth, self.metrix.spanHeight)
             node1 = self.metrix.node(self.edge.node1)
