@@ -46,8 +46,23 @@ def unquote(string):
 
 
 class Base(object):
+    basecolor = (255, 255, 255)
+    textcolor = (0, 0, 0)
     int_attrs = ['width', 'height']
 
+    @classmethod
+    def set_default_color(cls, color):
+        cls.basecolor = images.color_to_rgb(color)
+
+    @classmethod
+    def set_default_text_color(cls, color):
+        cls.textcolor = images.color_to_rgb(color)
+
+    @classmethod
+    def clear(cls):
+        cls.basecolor = (255, 255, 255)
+        cls.textcolor = (0, 0, 0)
+
     def duplicate(self):
         return copy.copy(self)
 
@@ -72,7 +87,6 @@ class Base(object):
 
 
 class Element(Base):
-    basecolor = (255, 255, 255)
     namespace = {}
 
     @classmethod
@@ -89,7 +103,10 @@ class Element(Base):
 
     @classmethod
     def clear(cls):
+        super(Element, cls).clear()
         cls.namespace = {}
+        cls.basecolor = (255, 255, 255)
+        cls.textcolor = (0, 0, 0)
 
     def __init__(self, id):
         self.id = unquote(id)
@@ -118,31 +135,26 @@ class Element(Base):
     def set_color(self, color):
         self.color = images.color_to_rgb(color)
 
+    def set_textcolor(self, color):
+        self.textcolor = images.color_to_rgb(color)
+
 
 class DiagramNode(Element):
-    basecolor = (255, 255, 255)
-    default_shape = 'box'
+    shape = 'box'
 
     @classmethod
     def set_default_shape(cls, shape):
-        cls.default_shape = shape
-
-    @classmethod
-    def set_default_color(cls, color):
-        cls.basecolor = images.color_to_rgb(color)
+        cls.shape = shape
 
     @classmethod
     def clear(cls):
         super(DiagramNode, cls).clear()
-        cls.default_shape = 'box'
-        cls.basecolor = (255, 255, 255)
+        cls.shape = 'box'
 
     def __init__(self, id):
         super(DiagramNode, self).__init__(id)
 
         self.label = unquote(id) or ''
-        self.shape = DiagramNode.default_shape
-        self.color = DiagramNode.basecolor
         self.style = None
         self.numbered = None
         self.icon = None
@@ -186,10 +198,6 @@ class DiagramNode(Element):
 class NodeGroup(Element):
     basecolor = (243, 152, 0)
 
-    @classmethod
-    def set_default_color(cls, color):
-        cls.basecolor = images.color_to_rgb(color)
-
     @classmethod
     def clear(cls):
         super(NodeGroup, cls).clear()
@@ -202,7 +210,6 @@ class NodeGroup(Element):
         self.level = 0
         self.separated = False
         self.shape = 'box'
-        self.color = NodeGroup.basecolor
         self.nodes = []
         self.edges = []
         self.orientation = 'landscape'
@@ -281,62 +288,6 @@ class NodeGroup(Element):
             sys.stderr.write(msg)
 
 
-class Diagram(NodeGroup):
-    linecolor = (0, 0, 0)
-    int_attrs = ['width', 'height', 'fontsize',
-                 'node_width', 'node_height', 'span_width', 'span_height']
-
-    @classmethod
-    def clear(cls):
-        super(NodeGroup, cls).clear()
-        cls.linecolor = (0, 0, 0)
-
-    def __init__(self):
-        super(Diagram, self).__init__(None)
-
-        self.node_width = None
-        self.node_height = None
-        self.span_width = None
-        self.span_height = None
-        self.page_padding = None
-        self.fontsize = None
-        self.edge_layout = None
-
-    def set_default_shape(self, value):
-        try:
-            noderenderer.get(value)
-            DiagramNode.set_default_shape(value)
-        except:
-            msg = "WARNING: unknown node shape: %s\n" % value
-            raise RuntimeError(msg)
-
-    def set_default_node_color(self, color):
-        color = images.color_to_rgb(color)
-        DiagramNode.set_default_color(color)
-
-    def set_default_line_color(self, color):
-        self.linecolor = images.color_to_rgb(color)
-        DiagramEdge.set_default_color(color)
-
-    def set_default_group_color(self, color):
-        color = images.color_to_rgb(color)
-        NodeGroup.set_default_color(color)
-
-    def set_shape_namespace(self, value):
-        noderenderer.set_default_namespace(value)
-
-    def set_edge_layout(self, value):
-        value = value.lower()
-        if value in ('normal', 'flowchart'):
-            msg = "WARNING: edge_layout is very experimental feature!\n"
-            sys.stderr.write(msg)
-
-            self.edge_layout = value
-        else:
-            msg = "WARNING: unknown edge dir: %s\n" % value
-            sys.stderr.write(msg)
-
-
 class DiagramEdge(Base):
     basecolor = (0, 0, 0)
     namespace = {}
@@ -410,12 +361,9 @@ class DiagramEdge(Base):
 
         return edges
 
-    @classmethod
-    def set_default_color(cls, color):
-        cls.basecolor = images.color_to_rgb(color)
-
     @classmethod
     def clear(cls):
+        super(DiagramEdge, cls).clear()
         cls.namespace = {}
         cls.basecolor = (0, 0, 0)
 
@@ -427,7 +375,7 @@ class DiagramEdge(Base):
 
         self.label = None
         self.dir = 'forward'
-        self.color = DiagramEdge.basecolor
+        self.color = self.basecolor
         self.style = None
         self.hstyle = None
         self.folded = None
@@ -484,3 +432,68 @@ class DiagramEdge(Base):
 
     def set_nofolded(self, value):
         self.folded = False
+
+
+class Diagram(NodeGroup):
+    _DiagramNode = DiagramNode
+    _DiagramEdge = DiagramEdge
+    _NodeGroup = NodeGroup
+    linecolor = (0, 0, 0)
+    int_attrs = ['width', 'height', 'fontsize',
+                 'node_width', 'node_height', 'span_width', 'span_height']
+
+    @classmethod
+    def clear(cls):
+        super(NodeGroup, cls).clear()
+        cls.linecolor = (0, 0, 0)
+
+    def __init__(self):
+        super(Diagram, self).__init__(None)
+
+        self.node_width = None
+        self.node_height = None
+        self.span_width = None
+        self.span_height = None
+        self.page_padding = None
+        self.fontsize = None
+        self.edge_layout = None
+
+    def set_default_shape(self, value):
+        try:
+            noderenderer.get(value)
+            DiagramNode.set_default_shape(value)
+        except:
+            msg = "WARNING: unknown node shape: %s\n" % value
+            raise RuntimeError(msg)
+
+    def set_default_text_color(self, color):
+        self.textcolor = images.color_to_rgb(color)
+        self._DiagramNode.set_default_text_color(self.textcolor)
+        self._NodeGroup.set_default_text_color(self.textcolor)
+        self._DiagramEdge.set_default_text_color(self.textcolor)
+
+    def set_default_node_color(self, color):
+        color = images.color_to_rgb(color)
+        self._DiagramNode.set_default_color(color)
+
+    def set_default_line_color(self, color):
+        self.linecolor = images.color_to_rgb(color)
+        self._DiagramEdge.set_default_color(self.linecolor)
+
+    def set_default_group_color(self, color):
+        color = images.color_to_rgb(color)
+        self._NodeGroup.set_default_color(color)
+
+    def set_shape_namespace(self, value):
+        noderenderer.set_default_namespace(value)
+
+    def set_edge_layout(self, value):
+        value = value.lower()
+        if value in ('normal', 'flowchart'):
+            msg = "WARNING: edge_layout is very experimental feature!\n"
+            sys.stderr.write(msg)
+
+            self.edge_layout = value
+        else:
+            msg = "WARNING: unknown edge dir: %s\n" % value
+            sys.stderr.write(msg)
