@@ -92,6 +92,10 @@ class ImageDrawEx(object):
         else:
             self.image = Image.new('RGB', size, (256, 256, 256))
 
+            # set transparency to background
+            alpha = Image.new('L', size, 1)
+            self.image.putalpha(alpha)
+
         self.filename = filename
         self.scale_ratio = kwargs.get('scale_ratio', 1)
         self.mode = kwargs.get('mode')
@@ -247,7 +251,7 @@ class ImageDrawEx(object):
             if self.scale_ratio == 1:
                 self.draw.text(xy, string, fill=fill)
             else:
-                size = self.textsize(string)
+                size = self.draw.textsize(string)
                 image = Image.new('RGBA', size)
                 draw = ImageDraw.Draw(image)
                 draw.text((0, 0), string, fill=fill)
