@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import re
 import urlutil
 try:
     from PIL import Image
@@ -34,16 +35,23 @@ except ImportError:
             @property
             def size(self):
                 try:
-                    return jpeg.JpegFile.get_size(self.filename)
+                    size = jpeg.JpegFile.get_size(self.filename)
                 except:
                     try:
                         if isinstance(self.filename, (str, unicode)):
-                            self.filename = open(self.filename, 'r')
-                        image = png.Reader(file=self.filename).read()
-                        return (image[0], image[1])
+                            content = open(self.filename, 'r')
+                        else:
+                            self.filename.seek(0)
+                            content = self.filename
+                        image = png.Reader(file=content).read()
+                        size = (image[0], image[1])
                     except:
-                        return None
+                        size = None
 
+                if hasattr(self.filename, 'seek'):
+                    self.filename.seek(0)
+
+                return size
 
 _image_size_cache = {}
 
@@ -72,3 +80,15 @@ def calc_image_size(size, bounded):
             size = (bounded[0], size[1] * bounded[0] / size[0])
 
     return size
+
+
+def color_to_rgb(color):
+    import webcolors
+    if color == 'none' or isinstance(color, (list, tuple)):
+        rgb = color
+    elif re.match('#', color):
+        rgb = webcolors.hex_to_rgb(color)
+    else:
+        rgb = webcolors.name_to_rgb(color)
+
+    return rgb
